pandoc_attributes: A parser and generator for pandoc block attributes
=====================================================================

Description
-----------

This is a simple parser / emitter for pandoc block attributes, intended
for use with pandocfilters.

License
-------

BSD 2-Clause License


Upstream Contact
----------------

- Author: Aaron O'Leary
- Home page: https://github.com/aaren/pandoc-attributes

Dependencies
------------

-  Python
-  setuptools
-  pandocfilters


Special Update/Build Instructions
---------------------------------

There are no release numbers, hence find the latest commit, download
https://github.com/aaren/pandoc-attributes/archive/${COMMIT}.zip and
rename it pandoc_attributes-${COMMIT:0:8}.zip
